# Contributing

>**tl;dr**
> Please take in consideration we are a small team.

As this project is light we are open to contributions.

For that please follow the steps below:
1. Fork the repository
2. Create a new branch
3. Make your changes
4. Commit your changes
5. Push to the branch
6. Create a pull request
7. Wait for review
8. If your pull request is accepted, you will be credited in the changelog and in the code.
